@@ -393,13 +393,16 @@ class GitConfiguration(SetupTask):
             confirm("Skipping git configuration because 'skip_git_config' is set in MWC settings")
             return True
         for key, value in self.get_expected_git_config().items():
-            if self.read_git_config(key) != value:
+            expected = value.strip().strip('"')
+            observed = self.read_git_config(key).strip().strip('"')
+            print(key, expected, observed, expected==observed)
+            if expected != observed:
                 return False
         return True
 
     def run_task(self):
         (Path.home() / ".gitconfig").touch()
-        for key, val in self.get_expected_git_config.items():
+        for key, val in self.get_expected_git_config().items():
             run(f'git config --global --replace-all {key} {val}', shell=True, check=True)
 
     def read_git_config(self, setting):
